@@ -1817,7 +1817,7 @@ scaled_from_pixdata (guchar * pixdata, int w, int h, int new_w, int new_h)
 }
 
 gboolean
-p_netk_read_hints (Window xwindow)
+p_netk_is_urgent (Window xwindow)
 {
     XWMHints *hints;
     gboolean retval;
@@ -1829,7 +1829,7 @@ p_netk_read_hints (Window xwindow)
     
     if (hints)
     {
-        retval  = (hints->flags & XUrgencyHint);
+        retval = (hints->flags & XUrgencyHint);
         XFree (hints);
         hints = NULL;
     }
