@@ -204,8 +204,6 @@ theme_name_to_dir(const gchar *base_path, const gchar *theme_name)
 {
 	GDir *dir;
 	gchar fullpath[PATH_MAX], *idx_theme_name;
-	XfceRc *rcfile;
-	const gchar *file;
 	
 	dir = g_dir_open(base_path, 0, NULL);
 	if(dir) {
@@ -651,6 +649,7 @@ search_fallback_paths(XfceIconThemeSingleton *singleton, const gchar *icon_name,
 	gchar *filename = NULL, buf[PATH_MAX];
 	const gchar *default_fallback_path = "/usr/share/pixmaps/";
 	const gchar *xfce_prefixed_fallback_path = DATADIR "/pixmaps/";
+	const gchar *user_fallback_path = "/.local/share/pixmaps/";
 	gint i, path_len;
 	const gchar **icon_ext;
 	
@@ -672,6 +671,7 @@ search_fallback_paths(XfceIconThemeSingleton *singleton, const gchar *icon_name,
 		buf[path_len] = 0;
 	}
 	
+	/* check /usr/share/pixmaps only if DATADIR != /usr/share */
 	if(!filename && strcmp(default_fallback_path, xfce_prefixed_fallback_path)) {
 		g_strlcpy(buf, default_fallback_path, PATH_MAX);
 		g_strlcat(buf, icon_name, PATH_MAX);
@@ -687,6 +687,23 @@ search_fallback_paths(XfceIconThemeSingleton *singleton, const gchar *icon_name,
 		}
 	}
 	
+	/* check ~/.local/share/pixmaps */
+	if(!filename) {
+		g_strlcpy(buf, xfce_get_homedir(), PATH_MAX);
+		g_strlcat(buf, user_fallback_path, PATH_MAX);
+		g_strlcat(buf, icon_name, PATH_MAX);
+		path_len = strlen(buf);
+		
+		for(i = 0; icon_ext[i]; i++) {
+			g_strlcat(buf, icon_ext[i], PATH_MAX);
+			if(g_file_test(buf, G_FILE_TEST_IS_REGULAR|G_FILE_TEST_IS_SYMLINK)) {
+				filename = g_strdup(buf);
+				break;
+			}
+			buf[path_len] = 0;
+		}
+	}
+	
 	return filename;
 }
 
